@@ -2,7 +2,13 @@
 require "test_helper"
 
 class ApplicationSystemTestCase < ActionDispatch::SystemTestCase
-  driven_by :selenium, using: :chrome, screen_size: [1400, 1400]
+  driven_by :selenium,
+    using: :chrome,
+    screen_size: [1400, 1400],
+    options: {
+      args: ["headless", "disable-gpu", "no-sandbox", "disable-dev-shm-usage"]
+    }
+
 
   teardown do
     # Adapted from https://medium.com/@coorasse/catch-javascript-errors-in-your-system-tests-89c2fe6773b1
